#
# spec file for package python-pycountry
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%{?sle15_python_module_pythons}
Name:           python-pycountry
Version:        23.12.11
Release:        2.4
Summary:        Databases for ISO standards 639 3166 3166-2 4217 15924
License:        LGPL-2.1-only
URL:            https://pypi.python.org/pypi/pycountry/
Source:         https://pypi.io/packages/source/p/pycountry/pycountry-%{version}.tar.gz
BuildRequires:  %{python_module pip}
BuildRequires:  %{python_module poetry-core}
BuildRequires:  %{python_module wheel}
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
Requires:       python-lxml
BuildArch:      noarch
# SECTION test requirements
BuildRequires:  %{python_module pytest}
BuildRequires:  %{python_module importlib-metadata}
# /SECTION
%python_subpackages

%description
pycountry provides the ISO databases for the standards 639 (Languages),
3166 (Countries), 3166-2 (Subdivisions of countries), 4217 (Currencies),
15924 (Scripts). The databases are imported from Debian's pkg-isocodes,
packaged into pycountry and made accessible through a Python API.
Translation files for the various strings are included as well.

%prep
%setup -q -n pycountry-%{version}

%build
%pyproject_wheel

%install
%pyproject_install
%python_expand %fdupes %{buildroot}%{$python_sitelib}

%check
%pytest

%files %{python_files}
%license LICENSE.txt
%doc README.rst
%{python_sitelib}/pycountry
%{python_sitelib}/pycountry-%{version}.dist-info

%changelog
* Mon Mar 11 2024 Steve Kowalik <steven.kowalik@suse.com>
- Add missing importlib-metadata BuildRequires.
* Sat Dec 30 2023 Dirk Müller <dmueller@suse.com>
- update to 23.12.11:
  * Added fallback to name when common_name or official_name
    country attributes are missing
  * Added support for adding and removing country records, as well
    as casting to dict
  * Improve performance speed by checking for non-ascii chars
    before removing accents
  * Added search_fuzzy method to subdivisions
  * Added type hinting, created py.typed file, and added mypy
    checks to CI
  * Dropped support for end-of-life Python 3.6 and 3.7.
  * Added support for Python 3.11 and Python 3.12.
  * Added dependency on importlib-resources for Python 3.8.
  * Dropped implicit dependency on setuptools for pkg_resources.
  * Update to iso-codes 4.15.0. (Thanks to alanorth!)
  * Removes iso3166.mo files and opts for newer iso3166-1.mo and
    iso3166-3.mo files for Country and Historic Country Translations
    respectively.
* Fri Apr 21 2023 Dirk Müller <dmueller@suse.com>
- add sle15_python_module_pythons (jsc#PED-68)
* Thu Apr 13 2023 Matej Cepl <mcepl@suse.com>
- Make calling of %%{sle15modernpython} optional.
* Sat Mar 26 2022 Dirk Müller <dmueller@suse.com>
- update to 22.3.5:
  * Update to iso-codes 4.9.0
* Tue Feb 15 2022 Dirk Müller <dmueller@suse.com>
- update to 22.1.0:
  * Update to iso-codes 4.8.0
* Mon Sep 28 2020 Dirk Mueller <dmueller@suse.com>
- update to 20.7.3:
  - Fix bug #37: (accidental) unconditional pkg_resources import.
  - Add (auto-generated) __version__ attribute to the main module.
  - Add fuzzy search to historic countries. (Fixe issue #26)
  - Update to iso-codes 4.5.0.
  - PR 9: Clean up the normalization (lower casing) of values in indexes and searches.
    See PR https://github.com/flyingcircusio/pycountry/pull/9 for detailed
    discussion. This also fixed issue #8.
  - Smaller cleanups and build environment version bumps.
  - PR 35: Python 3-only cleanups and updated Python minor version compatibility
  - PR 33: Remove defunct bugtracker link from README (thanks, jwilk)
  - P3 32: (Somewhat hilarious) Typo (thanks, jwilk)
  - Moved to Git/Github; switched from Bitbucket Pipelines to Travis builds.
* Tue Sep 10 2019 Tomáš Chvátal <tchvatal@suse.com>
- Update to 19.8.18:
  * Various country fixes
- Remove merged patch pycountry-19.7.15-fix-reading-description.patch
* Fri Aug 16 2019 Matthias Fehring <buschmann23@opensuse.org>
- add pycountry-19.7.15-fix-reading-description.patch to fix wrong
  encoding when opening description files in setup.py
* Tue Jul 23 2019 Tomáš Chvátal <tchvatal@suse.com>
- Update to 19.7.15:
  * Updates for more countries and various fixes
* Fri Mar 29 2019 pgajdos@suse.com
- version update to 18.12.8
  - Switch API from "get + KeyError" to " get + default=None". This is
    a subtle API-breaking change. Please update carefully. (#13416)
  - Update to iso-codes 4.1.
  - Fix #13394: incorrect KeyError shadowing in Subdivisions.get()
  - Fix #13398: make lazy loading thread-safe.
- run unit tests
* Sat Sep 16 2017 smurf.anon@gmail.com
- Update to version 17.5.14
- Convert to singlespec
* Wed Oct  5 2016 mailaender@opensuse.org
- update to version 1.20
* Wed Oct  8 2008 Ciaran Farrell <cfarrell1980@googlemail.com>
- Initial import and build of version 0.10
